@@ -7,17 +7,19 @@
 #'     specified with argument \code{x} and returns a corresponding
 #'     \code{\linkS4class{EnsDb}} object.
 #'
-#' @details By providing the connection to a MySQL database, it is possible
-#'     to use MySQL as the database backend and queries will be performed on
-#'     that database. Note however that this requires the package \code{RMySQL}
-#'     to be installed. In addition, the user needs to have access to a MySQL
-#'     server providing already an EnsDb database, or must have write
-#'     privileges on a MySQL server, in which case the \code{\link{useMySQL}}
-#'     method can be used to insert the annotations from an EnsDB package into
-#'     a MySQL database.
+#' @details
+#'
+#' By providing the connection to a MariaDB/MySQL database, it is possible
+#' to use MariaDB/MySQL as the database backend and queries will be performed on
+#' that database. Note however that this requires the package \code{RMariaDB}
+#' to be installed. In addition, the user needs to have access to a MySQL
+#' server providing already an EnsDb database, or must have write
+#' privileges on a MySQL server, in which case the \code{\link{useMySQL}}
+#' method can be used to insert the annotations from an EnsDB package into
+#' a MySQL database.
 #' 
 #' @param x Either a character specifying the \emph{SQLite} database file, or
-#'     a \code{DBIConnection} to e.g. a MySQL database.
+#'     a \code{DBIConnection} to e.g. a MariaDB/MySQL database.
 #' 
 #' @return A \code{\linkS4class{EnsDb}} object.
 #' 
@@ -35,8 +37,9 @@
 #'
 #' ## Third way: connect to a MySQL database
 #' \dontrun{
-#' library(RMySQL)
-#' dbcon <- dbConnect(MySQL(), user = my_user, pass = my_pass, host = my_host, dbname = "ensdb_hsapiens_v86")
+#' library(RMariaDB)
+#' dbcon <- dbConnect(MySQL(), user = my_user, pass = my_pass,
+#'     host = my_host, dbname = "ensdb_hsapiens_v86")
 #' edb <- EnsDb(dbcon)
 #' }
 EnsDb <- function(x){
@@ -65,9 +68,10 @@ EnsDb <- function(x){
     tables <- dbListTables(con)
     ## read the columns for these tables.
     Tables <- vector(length=length(tables), "list")
-    for(i in 1:length(Tables)){
-        Tables[[ i ]] <- colnames(dbGetQuery(con, paste0("select * from ",
-                                                         tables[ i ], " limit 1")))
+    for (i in 1:length(Tables)) {
+        Tables[[i]] <- colnames(dbGetQuery(con,
+                                           paste0("select * from ",
+                                                  tables[ i ], " limit 1")))
     }
     names(Tables) <- tables
     EDB <- new("EnsDb", ensdb = con, tables = Tables)
@@ -193,15 +197,15 @@ prefixColumnsKeepOrder <- function(x, columns, clean = TRUE, with.tables) {
 )
 ## Takes the names of two tables, determines how to join them and returns the
 ## join query row, if found.
-joinTwoTables <- function(a, b) {
-    gotIt <- which((.JOINS2[, 1] %in% a & .JOINS2[, 2] %in% b) |
-                   (.JOINS2[, 2] %in% a & .JOINS2[, 1] %in% b))
-    if (length(gotIt) == 0) {
+joinTwoTables <- function(a, b, mysql = FALSE) {
+    jns <- .JOINS2
+    gotIt <- which((jns[, 1] %in% a & jns[, 2] %in% b) |
+                   (jns[, 2] %in% a & jns[, 1] %in% b))
+    if (length(gotIt))
+        jns[gotIt[1], ]
+    else
         stop("Table(s) ", paste(a, collapse = ", "), " can not be joined with ",
              paste(b, collapse = ", "), "!")
-    } else {
-        return(.JOINS2[gotIt[1], ])
-    }
 }
 ## x: EnsDb.
 ## tab: tables to join.
@@ -233,9 +237,10 @@ joinQueryOnTables2 <- function(x, tab, join = "suggested", startWith = NULL) {
         tab <- tab[-1]
     }
     Query <- alreadyUsed
+    mysql <- is(dbconn(x), "MariaDBConnection")
     ## Iteratively build the query.
     while (length(tab) > 0) {
-        res <- joinTwoTables(a = alreadyUsed, b = tab)
+        res <- joinTwoTables(a = alreadyUsed, b = tab, mysql = mysql)
         newTab <- res[1:2][!(res[1:2] %in% alreadyUsed)]
         ## Could also use the suggested join which is in element 4.
         Query <- paste(Query, ifelse(join == "suggested", res[4], join),
@@ -614,17 +619,17 @@ dbHasValidTables <- function(con, returnError = TRUE,
 ##
 ##
 feedEnsDb2MySQL <- function(x, mysql, verbose = TRUE) {
-    if (!inherits(mysql, "MySQLConnection"))
+    if (!inherits(mysql, "MariaDBConnection"))
         stop("'mysql' is supposed to be a connection to a MySQL database.")
     ## Fetch the tables and feed them to MySQL.
     sqlite_con <- dbconn(x)
     tabs <- dbListTables(sqlite_con)
     for (the_table in tabs) {
         if (verbose)
-            message("Fetch table ", the_table, "...", appendLF = FALSE)
+            message("Fetch table ", the_table, " ... ", appendLF = FALSE)
         tmp <- dbGetQuery(sqlite_con, paste0("select * from ", the_table, ";"))
         if (verbose)
-            message("OK\nStoring the table in MySQL...", appendLF = FALSE)
+            message("OK\nStoring the table in MySQL ... ", appendLF = FALSE)
         ## Fix tx_cds_seq_start being a character in old databases
         if (any(colnames(tmp) == "tx_cds_seq_start")) {
             suppressWarnings(
@@ -634,58 +639,89 @@ feedEnsDb2MySQL <- function(x, mysql, verbose = TRUE) {
                 tmp[, "tx_cds_seq_end"] <- as.integer(tmp[, "tx_cds_seq_end"])
             )
         }
-        dbWriteTable(mysql, tmp, name = the_table, row.names = FALSE)
+        dbWriteTable(mysql, tmp, name = the_table, row.names = FALSE,
+                     field.types = vapply(tmp, .mysql_datatype, character(1)))
         if (verbose)
             message("OK")
     }
     ## Create the indices.
     if (verbose)
         message("Creating indices...", appendLF = FALSE)
-    ## Guess index length on the maximal number of characters of an ID.
-    indexLength <- max(nchar(
-        dbGetQuery(sqlite_con, "select distinct gene_id from gene")$gene_id
-    ))
-    .createEnsDbIndices(mysql, indexLength = paste0("(", indexLength, ")"),
-                        proteins = hasProteinData(x))
+    .createEnsDbIndices(mysql, proteins = hasProteinData(x))
     if (verbose)
         message("OK")
     return(TRUE)
 }
-## Small helper function to cfeate all the indices.
-.createEnsDbIndices <- function(con, indexLength = "", proteins = FALSE) {
+
+#' Instead of using the default dbDataType function we define here a more
+#' fine-grained data type definition.
+#' @noRd
+.mysql_datatype <- function(x) {
+    res <- "TEXT"
+    if (any(is.na(x)) & any(!is.na(x)))
+        x <- x[!is.na(x)]
+    if (is.character(x)) {
+        nc <- max(nchar(x))
+        if (nc < 65535)
+            res <- paste0("VARCHAR(", nc, ")")
+        else res <- "MEDIUMTEXT"
+    }
+    if (is.logical(x))
+        res <- "TINYINT"
+    if (is.numeric(x)) {
+        if (is.integer(x)) {
+            res <- "INT"
+            if (any(x < -2147483648 | x > 2147483647))
+                res <- "BIGINT"
+            if (all(x > -8388608 & x < 8388607))
+                res <- "MEDIUMINT"
+            if (all(x > -32768 & x < 32767))
+                res <- "SMALLINT"
+            if (all(x > -128 & x < 127))
+                res <- "TINYINT"
+        } else res <- "DOUBLE"
+    }
+    res
+}
+
+#' Small helper function to create all the indices.
+#'
+#' @param con database connection.
+#'
+#' @param mysql `logical(1)` indicating whether indices specific for
+#'     MariaDB/MySQL databases should be created.
+#'
+#' @param proteins `logical(1)` whether indices for protein tables should be
+#'     created too.
+#'
+#' @noRd
+.createEnsDbIndices <- function(con, proteins = FALSE) {
     indexCols <- c(chromosome = "seq_name", gene = "gene_id", gene = "gene_name",
                    gene = "seq_name", tx = "tx_id", tx = "gene_id",
                    exon = "exon_id", tx2exon = "tx_id", tx2exon = "exon_id")
-    if (as.numeric(dbSchemaVersion(con)) > 1)
+    idxType <- c(chromosome = "unique", gene = "unique", gene = "", gene = "",
+                 tx = "unique", tx = "", exon = "unique", tx2exon = "",
+                 tx2exon = "")
+    if (as.numeric(dbSchemaVersion(con)) > 1) {
         indexCols <- c(indexCols,
                        entrezgene = "gene_id", entrezgene = "entrezid")
+        idxType <- c(idxType, entrezgene = "", entrezgene = "")
+    }
     if (proteins) {
-        indexCols <- c(indexCols,
-                       protein = "tx_id",
-                       protein = "protein_id",
-                       uniprot = "protein_id",
-                       uniprot = "uniprot_id",
+        indexCols <- c(indexCols, protein = "tx_id", protein = "protein_id",
+                       uniprot = "protein_id", uniprot = "uniprot_id",
                        protein_domain = "protein_domain_id",
                        protein_domain = "protein_id")
+        idxType <- c(idxType, protein = "", protein = "", uniprot = "",
+                     uniprot = "", protein_domain = "", protein_domain = "")
     }
     for (i in 1:length(indexCols)) {
         tabname <- names(indexCols)[i]
         colname <- indexCols[i]
-        ## Check if we've got any values at all. if not we're not creating the
-        ## index.
-        ids <- dbGetQuery(con, paste0("select distinct ", colname,
-                                      " from ", tabname))[, colname]
-        if (length(ids) == 0 | all(is.na(ids))) {
-            ## No need to make an index here!
-        } else {
-            if (indexLength != "")
-                idxL <- paste0("(", min(c(max(nchar(ids)), 20)), ")")
-            else
-                idxL <- ""
-            aff_rows <- dbExecute(
-                con, paste0("create index ", tabname, "_", colname, "_idx ",
-                            "on ", tabname, " (",colname, idxL,")"))
-        }
+        idx_tp <- idxType[i]
+        tmp <- dbExecute(con, paste0("create ", idx_tp, " index ",
+                                     tabname, "_", colname, "_idx on ",
+                                     tabname, " (", colname, ")"))
     }
     ## Add the one on the numeric index:
     aff_rows <- dbExecute(con, paste0("create index tx2exon_exon_idx_idx on ",
@@ -695,31 +731,35 @@ feedEnsDb2MySQL <- function(x, mysql, verbose = TRUE) {
 ############################################################
 ## listEnsDbs
 ## list databases
-#' @title List EnsDb databases in a MySQL server
+#' @title List EnsDb databases in a MariaDB/MySQL server
 #'
-#' @description The \code{listEnsDbs} function lists EnsDb databases in a
-#'     MySQL server.
+#' @description
 #'
-#' @details The use of this function requires that the \code{RMySQL} package
-#'     is installed and that the user has either access to a MySQL server with
-#'     already installed EnsDb databases, or write access to a MySQL server in
-#'     which case EnsDb databases could be added with the \code{\link{useMySQL}}
-#'     method. EnsDb databases follow the same naming conventions than the EnsDb
-#'     packages, with the exception that the name is all lower case and that
-#'     \code{"."} is replaced by \code{"_"}.
+#' The \code{listEnsDbs} function lists EnsDb databases in a
+#' MariaDB/MySQL server.
+#'
+#' @details
+#'
+#' The use of this function requires the \code{RMariaDB} package
+#' to be installed. In addition user credentials to access a MySQL server
+#' (with already installed EnsDb databases), or with write access are required.
+#' For the latter EnsDb databases can be added with the \code{\link{useMySQL}}
+#' method. EnsDb databases in a MariaDB/MySQL server follow the same naming
+#' conventions than EnsDb packages, with the exception that the name is all
+#' lower case and that each \code{"."} is replaced by \code{"_"}.
 #' 
-#' @param dbcon A \code{DBIConnection} object providing access to a MySQL
-#'     database. Either \code{dbcon} or all of the other arguments have to be
-#'     specified.
+#' @param dbcon A \code{DBIConnection} object providing access to a
+#'     MariaDB/MySQL database. Either \code{dbcon} or all of the other
+#'     arguments have to be specified.
 #' 
 #' @param host Character specifying the host on which the MySQL server is
 #'     running.
 #' 
-#' @param port The port of the MySQL server (usually \code{3306}).
+#' @param port The port of the MariaDB/MySQL server (usually \code{3306}).
 #' 
-#' @param user The username for the MySQL server.
+#' @param user The username for the MariaDB/MySQL server.
 #' 
-#' @param pass The password for the MySQL server.
+#' @param pass The password for the MariaDB/MySQL server.
 #' 
 #' @return A \code{data.frame} listing the database names, organism name
 #'     and Ensembl version of the EnsDb databases found on the server.
@@ -730,18 +770,18 @@ feedEnsDb2MySQL <- function(x, mysql, verbose = TRUE) {
 #' 
 #' @examples
 #' \dontrun{
-#' library(RMySQL)
-#' dbcon <- dbConnect(MySQL(), host = "localhost", user = my_user, pass = my_pass)
+#' library(RMariaDB)
+#' dbcon <- dbConnect(MariaDB(), host = "localhost", user = my_user, pass = my_pass)
 #' listEnsDbs(dbcon)
 #' }
 listEnsDbs <- function(dbcon, host, port, user, pass) {
-    if(requireNamespace("RMySQL", quietly = TRUE)) {
+    if(requireNamespace("RMariaDB", quietly = TRUE)) {
         if (missing(dbcon)) {
             if (missing(host) | missing(user) | missing(port) | missing(host))
                 stop("Arguments 'host', 'port', 'user' and 'pass' are required",
                      " if 'dbcon' is not specified.")
-            dbcon <- dbConnect(RMySQL::MySQL(), host = host, port = port, user = user,
-                               pass = pass)
+            dbcon <- dbConnect(RMariaDB::MariaDB(), host = host, port = port,
+                               user = user, pass = pass)
         }
         dbs <- dbGetQuery(dbcon, "show databases;")
         edbs <- dbs[grep(dbs$Database, pattern = "^ensdb_"), "Database"]
@@ -757,7 +797,7 @@ listEnsDbs <- function(dbcon, host, port, user, pass) {
         }
         return(edbTable)
     } else {
-        stop("Required package 'RMySQL' is not installed.")
+        stop("Required package 'RMariaDB' is not installed.")
     }
 }
 
