@@ -26,7 +26,7 @@ supportedFilters(edb)
  
 
 ## ----transcripts-----------------------------------------------------------
-Tx <- transcripts(edb, filter = list(GenenameFilter("BCL2L11")))
+Tx <- transcripts(edb, filter = GeneNameFilter("BCL2L11"))
 
 Tx
 
@@ -39,7 +39,7 @@ head(Tx$tx_biotype)
 
 ## ----transcripts-filter-expression-----------------------------------------
 ## Use a filter expression to perform the filtering.
-transcripts(edb, filter = ~ genename == "ZBTB16")
+transcripts(edb, filter = ~ gene_name == "ZBTB16")
  
 
 ## ----transcripts-filter, message = FALSE-----------------------------------
@@ -92,7 +92,7 @@ gn <- genes(edb, filter = grf)
 gn
 
 ## Next we retrieve all transcripts for that gene so that we can plot them.
-txs <- transcripts(edb, filter = GenenameFilter(gn$gene_name))
+txs <- transcripts(edb, filter = GeneNameFilter(gn$gene_name))
  
 
 ## ----granges-zbtb16, message = FALSE, echo = FALSE-------------------------
@@ -126,7 +126,7 @@ listTxbiotypes(edb)
 ## We're going to fetch all genes which names start with BCL.
 BCLs <- genes(edb,
 	      columns = c("gene_name", "entrezid", "gene_biotype"),
-	      filter = GenenameFilter("BCL", condition = "startsWith"),
+	      filter = GeneNameFilter("BCL", condition = "startsWith"),
 	      return.type = "DataFrame")
 nrow(BCLs)
 BCLs
@@ -319,19 +319,19 @@ plotTracks(list(gat, GeneRegionTrack(protCod, name = "protein coding"),
 seqlevelsStyle <- "Ensembl"
  
 
-## ----pplot-plot, message = FALSE-------------------------------------------
-library(ggbio)
+## ----pplot-plot, message = FALSE, eval = FALSE-----------------------------
+#  library(ggbio)
+#  
+#  ## Create a plot for all transcripts of the gene SKA2
+#  autoplot(edb, ~ gene_name == "SKA2")
+#  
 
-## Create a plot for all transcripts of the gene SKA2
-autoplot(edb, ~ genename == "SKA2")
- 
-
-## ----pplot-plot-2, message = FALSE-----------------------------------------
-## Get the chromosomal region in which the gene is encoded
-ska2 <- genes(edb, filter = ~ genename == "SKA2")
-strand(ska2) <- "*"
-autoplot(edb, GRangesFilter(ska2), names.expr = "gene_name")
- 
+## ----pplot-plot-2, message = FALSE, eval = FALSE---------------------------
+#  ## Get the chromosomal region in which the gene is encoded
+#  ska2 <- genes(edb, filter = ~ gene_name == "SKA2")
+#  strand(ska2) <- "*"
+#  autoplot(edb, GRangesFilter(ska2), names.expr = "gene_name")
+#  
 
 ## ----AnnotationDbi, message = FALSE----------------------------------------
 library(EnsDb.Hsapiens.v86)
@@ -364,7 +364,7 @@ select(edb, keys = c("BCL2", "BCL2L11"), keytype = "GENENAME",
        columns = c("GENEID", "GENENAME", "TXID", "TXBIOTYPE"))
 
 ## Use the filtering system of ensembldb
-select(edb, keys = ~ genename %in% c("BCL2", "BCL2L11") &
+select(edb, keys = ~ gene_name %in% c("BCL2", "BCL2L11") &
 		tx_biotype == "protein_coding",
        columns = c("GENEID", "GENENAME", "TXID", "TXBIOTYPE"))
  
@@ -378,7 +378,7 @@ mapIds(edb, keys = c("BCL2", "BCL2L11"), column = "TXID", keytype = "GENENAME",
        multiVals = "list")
 
 ## And, just like before, we can use filters to map only to protein coding transcripts.
-mapIds(edb, keys = list(GenenameFilter(c("BCL2", "BCL2L11")),
+mapIds(edb, keys = list(GeneNameFilter(c("BCL2", "BCL2L11")),
                         TxBiotypeFilter("protein_coding")), column = "TXID",
        multiVals = "list")
  
